@@ -11,7 +11,7 @@
 //! * copy the self exe to $ELAN_HOME/bin
 //! * hardlink lean, etc to *that*
 //! * update the PATH in a system-specific way
-//! * run the equivalent of `elan default stable`
+//! * run the equivalent of `elan default nightly`
 //!
 //! During upgrade (`elan self upgrade`):
 //!
@@ -32,6 +32,7 @@
 
 use common::{self, Confirm};
 use elan_dist::dist;
+use elan_dist::dist::ToolchainDesc;
 use elan_utils::utils;
 use errors::*;
 use flate2;
@@ -69,9 +70,9 @@ macro_rules! pre_install_msg_template {
 
 This will download and install Elan, a tool for managing different Lean versions used in
 packages you create or download. It will also install a default version of Lean and its package
-manager, leanpkg, for editing files not belonging to any package.
+manager, lake, for editing files not belonging to any package.
 
-It will add the `leanpkg`, `lean`, and `elan` commands to
+It will add the `lake`, `lean`, and `elan` commands to
 Elan's bin directory, located at:
 
     {elan_home_bin}
@@ -462,7 +463,7 @@ fn customize_install(mut opts: InstallOpts) -> Result<InstallOpts> {
     println!("");
 
     opts.default_toolchain = common::question_str(
-        "Default toolchain? (stable/nightly/none)",
+        "Default toolchain? (nightly/<specific version>/none)",
         &opts.default_toolchain,
     )?;
 
@@ -505,8 +506,8 @@ pub fn install_proxies() -> Result<()> {
     // proxies. In that case our process may actually have the `elan.exe`
     // file open, and on systems like Windows that means that you can't
     // even remove other hard links to the same file. Basically if we have
-    // `elan.exe` open and running and `leanpkg.exe` is a hard link to that
-    // file, we can't remove `leanpkg.exe`.
+    // `elan.exe` open and running and `lean.exe` is a hard link to that
+    // file, we can't remove `lean.exe`.
     //
     // To avoid unnecessary errors from being returned here we use the
     // `same-file` crate and its `Handle` type to avoid clobbering hard links
@@ -548,11 +549,12 @@ fn maybe_install_lean(toolchain_str: &str, verbose: bool) -> Result<()> {
         info!("skipping toolchain installation");
         println!("");
     } else if cfg.find_default()?.is_none() {
-        let toolchain = cfg.get_toolchain(toolchain_str, false)?;
+        let desc = ToolchainDesc::from_str(toolchain_str)?;
+        let toolchain = cfg.get_toolchain(&desc, false)?;
         let status = toolchain.install_from_dist(false)?;
-        cfg.set_default(toolchain_str)?;
+        cfg.set_default(&desc)?;
         println!("");
-        common::show_channel_update(cfg, toolchain_str, Ok(status))?;
+        common::show_channel_update(cfg, &desc, Ok(status))?;
     } else {
         info!("updating existing elan installation");
         println!("");
@@ -598,7 +600,7 @@ pub fn uninstall(no_prompt: bool) -> Result<()> {
 
     let read_dir_err = "failure reading directory";
 
-    info!("removing leanpkg home");
+    info!("removing elan home");
 
     // Remove ELAN_HOME/bin from PATH
     let ref remove_path_methods = get_remove_path_methods()?;
